package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsCapacity;
import com.steerinfo.dil.model.RmsConsignee;
import com.steerinfo.dil.service.impl.RmsConsigneeServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/${api.version}/rmsconsignee")
public class RmsConsigneeController extends BaseRESTfulController {
    @Autowired
    RmsConsigneeServiceImpl rmsConsigneeService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    @ApiOperation(value = "模糊查询展示客户信息表", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "407", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getConsigneeList")
    public RESTfulResult getConsigneeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String con) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_consignee_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsConsigneeService.getConsigneeList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_consignee_list");
            //添加id
            map.put("indexId", "consigneeId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsConsigneeService.getConsigneeList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsConsigneeService.getConsigneeList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    /**
     * 创建收货客户信息
     * @param
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsConsignee对象创建")
    @ApiImplicitParam(name = "rmsCapacity", value = "详细实体rmsConsignee", required = true, dataType = "RmsCapacity")
    @PostMapping(value = "/insertConsignee")
    public RESTfulResult insertConsignee(@RequestBody Map<String,Object> mapVal)throws ParseException {
        int result = rmsConsigneeService.insertConsignee(mapVal);
        if(result==-1){
            return failed();
        }
        return success(result);
    }

    /**
     * 根据id更新客户信息
     * @param
     * @return
     */

    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsConsignee信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short"),
            @ApiImplicitParam(name = "rmsConsignee", value = "详细实体rmsConsignee", required = true, dataType = "RmsConsignee")
    })
    @PostMapping(value = "/updateConsignee", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateConsignee( @RequestBody Map<String,Object> mapVal )throws ParseException{
        int result = rmsConsigneeService.updateConsignee(mapVal);
        return success(result);
    }

    /**
     * 根据id删除客户信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short")
    @PostMapping(value = "/deleteConsignee/{id}")
    public RESTfulResult deleteConsignee(@PathVariable("id") BigDecimal id){
        return success(rmsConsigneeService.deleteConsignee(id));
    }

    /**
     * 根据id获取客户信息
     * @param id
     * @return
     */
    @ApiOperation(value="获取客户信息详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getConsigneeById/{id}")
    public RESTfulResult getConsigneeById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> list= rmsConsigneeService.getConsigneeById(id);
        return success(list);
    }

}
